@@ -79,11 +79,11 @@ class GeographyTimezoneTestCase(PluginTestCase):
                 "timezone New York", r"America/New_York \(currently UTC-[45]\)"
             )
 
-        tz = pytz.timezone("Canada/Newfoundland")
+        tz = pytz.timezone("America/St_Johns")
         with patch.object(wikidata, "timezone_from_uri", return_value=tz):
             self.assertRegexp(
                 "timezone Newfoundland",
-                r"Canada/Newfoundland \(currently UTC-[23]:30\)",
+                r"America/St_Johns \(currently UTC-[23]:30\)",
             )
 
         tz = pytz.timezone("Asia/Kolkata")
@@ -107,11 +107,11 @@ class GeographyTimezoneTestCase(PluginTestCase):
                 "timezone New York", r"America/New_York \(currently UTC-[45]\)"
             )
 
-        tz = zoneinfo.ZoneInfo("Canada/Newfoundland")
+        tz = zoneinfo.ZoneInfo("America/St_Johns")
         with patch.object(wikidata, "timezone_from_uri", return_value=tz):
             self.assertRegexp(
                 "timezone Newfoundland",
-                r"Canada/Newfoundland \(currently UTC-[23]:30\)",
+                r"America/St_Johns \(currently UTC-[23]:30\)",
             )
 
         tz = zoneinfo.ZoneInfo("Asia/Kolkata")
